/*
 * file StpReleasable.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.StpReleasable
 *
 * (C) Copyright IBM Corporation 2004, 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */


package com.ibm.rational.wvcm.stp;

/**
 * A interface for objects that hold resources that can (and in some
 * cases really should) be released prior to garbage collection.
 */
public interface StpReleasable {

    /**
     * A distinguished unchecked exception for use by implementations
     * of Releasable.
     * 
     * Implementations of Releasable should document if they actually
     * throw this exception, under what conditions it occurs and what
     * to expect for the exception's "cause" (Throwable.getCause()).
     * 
     * <p>See {@link java.lang.Throwable} for a description of this general
     * idiom of documenting/returning unchecked exceptions from
     * general interfaces.
     */    
    public static class ReleaseException extends RuntimeException
    {
        /**
         * 
         */
        private static final long serialVersionUID = -6014447477020398274L;

        public ReleaseException(Throwable ex) {
            super(ex);
        }
    }
    
    /**
     * Release the resources held by this object.
     * 
     * Class's Javadoc comments indicate whether or not the unchecked
     * ReleaseException can be thrown.
     */
    void release();
}
